package WebGUI::i18n::Dutch::Asset_Photo;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1201193472',
    'message' => 'Foto'
  },
  'comment message' => {
    'lastUpdated' => '1201193528',
    'message' => 'Uw commentaar is toegevoegd. <a href="%s">Terug naar foto</a>.'
  },
  'commentForm error no bodyText' => {
    'lastUpdated' => '1204900977',
    'message' => 'Er was geen tekst ingevoerd. Voer tekst in om commentaar te geven.'
  },
  'commentForm error no commentId' => {
    'lastUpdated' => '1204901022',
    'message' => 'Er was geen commentaar ID gegeven. Dit duidt op een probleem met het sjabloon. Licht een beheerder in.'
  },
  'delete message' => {
    'lastUpdated' => '1201193563',
    'message' => 'De foto is verwijderd. <a href="%s">Ga terug naar album</a>.'
  },
  'editCommentSave message' => {
    'lastUpdated' => '1204901066',
    'message' => 'Het commentaar is vernieuwd. <a href="%s">Terug naar foto</a>.'
  },
  'editForm cancel' => {
    'lastUpdated' => '1204031282',
    'message' => 'Annuleren'
  },
  'editForm friendsOnly' => {
    'lastUpdated' => '1204031292',
    'message' => 'Alleen vrienden'
  },
  'editForm keywords' => {
    'lastUpdated' => '1204031301',
    'message' => 'Labels'
  },
  'editForm location' => {
    'lastUpdated' => '1204031310',
    'message' => 'Locatie'
  },
  'editForm photo new' => {
    'lastUpdated' => '1204031319',
    'message' => 'Nieuwe foto'
  },
  'editForm photo replace' => {
    'lastUpdated' => '1204031328',
    'message' => 'Vervang foto'
  },
  'editForm save' => {
    'lastUpdated' => '1204031337',
    'message' => 'Opslaan'
  },
  'editForm synopsis label' => {
    'lastUpdated' => '1204031345',
    'message' => 'Beschrijving'
  },
  'editForm title label' => {
    'lastUpdated' => '1204031355',
    'message' => 'Titel'
  },
  'error no image' => {
    'lastUpdated' => '1276684373',
    'message' => 'U moet een afbeelding selecteren om te uploaden.'
  },
  'error no space' => {
    'lastUpdated' => '1213629815',
    'message' => 'Er is niet genoeg diskruimte om dit bestand te uploaden'
  },
  'form comment save comment' => {
    'lastUpdated' => '1231520743',
    'message' => 'Commentaar opslaan'
  },
  'help commentForm body' => {
    'lastUpdated' => '1201193623',
    'message' => 'Met deze sjabloon variabelen wordt het formulier gemaakt waar gebruikers commentaar kunnen geven bij fotos.'
  },
  'help commentForm title' => {
    'lastUpdated' => '1203517022',
    'message' => 'Foto - Commentaar formulier'
  },
  'help common body' => {
    'lastUpdated' => '1201252775',
    'message' => 'Deze sjabloon variabelen worden gedeeld door alle soorten sjablonen die voor het foto asset gebruikt kunnen worden.'
  },
  'help common title' => {
    'lastUpdated' => '1201252862',
    'message' => 'Foto - Standaard'
  },
  'help delete body' => {
    'lastUpdated' => '1201252927',
    'message' => 'Bevestig het verwijderen een foto asset'
  },
  'help delete title' => {
    'lastUpdated' => '1201252971',
    'message' => 'Foto - Verwijder formulier'
  },
  'help edit body' => {
    'lastUpdated' => '1201254791',
    'message' => 'Deze sjabloon variabelen maken het formulier waarmee foto assets toegevoegd en bewerkt kunnen worden.'
  },
  'help edit title' => {
    'lastUpdated' => '1201254807',
    'message' => 'Foto bewerk formulier'
  },
  'help editComment body' => {
    'lastUpdated' => '1204901124',
    'message' => 'De variabelen zijn beschikbaar voor de foto commentaar bewerk pagina.'
  },
  'help editComment title' => {
    'lastUpdated' => '1204901153',
    'message' => 'Foto commentaar bewerk sjabloon'
  },
  'help makeShortcut body' => {
    'lastUpdated' => '1201264390',
    'message' => 'Deze sjabloon variabelen maken het formulier waarmee foto assets gelinkt kunnen worden. '
  },
  'help makeShortcut title' => {
    'lastUpdated' => '1201256433',
    'message' => 'Foto - Maak snelkoppeling formulier'
  },
  'help view body' => {
    'lastUpdated' => '1201256492',
    'message' => 'Deze sjabloon variabelen maken het mogelijk het normale uiterlijk te maken voor foto assets.'
  },
  'help view title' => {
    'lastUpdated' => '1201256508',
    'message' => 'Foto -Normaal uiterlijk'
  },
  'helpvar album_menuTitle' => {
    'lastUpdated' => '1213629843',
    'message' => 'De menu titel van het album dat dit bestand bevat'
  },
  'helpvar album_thumbnailUrl' => {
    'lastUpdated' => '1213629881',
    'message' => 'Het URL van de miniatuur afbeelding van het albumk dat dit bestand bevat.'
  },
  'helpvar album_title' => {
    'lastUpdated' => '1213629942',
    'message' => 'De titel van het album dat dit bestand bevat'
  },
  'helpvar album_url' => {
    'lastUpdated' => '1213629966',
    'message' => 'Het URL van het album dat dit bestand bevat'
  },
  'helpvar canComment' => {
    'lastUpdated' => '1201256537',
    'message' => 'Dit is waar wanneer de huidige gebruiker commentaar kan geven bij deze foto.'
  },
  'helpvar canEdit' => {
    'lastUpdated' => '1203517035',
    'message' => 'Dit is waar wanneer de huidige gebruiker deze foto kan bewerken.'
  },
  'helpvar commentForm_bodyText' => {
    'lastUpdated' => '1201258284',
    'message' => 'Het hoofdveld van het commentaar. Een Rich editor zoals geconfigureerd in de ouder Asset, de galerie.'
  },
  'helpvar commentForm_end' => {
    'lastUpdated' => '1201258304',
    'message' => 'Beeindig het commentaar formulier.'
  },
  'helpvar commentForm_start' => {
    'lastUpdated' => '1201258318',
    'message' => 'Begin het commentaar formulier'
  },
  'helpvar commentForm_submit' => {
    'lastUpdated' => '1201258752',
    'message' => 'Verstuur het commentaar formulier.'
  },
  'helpvar commentLoop' => {
    'lastUpdated' => '1201264270',
    'message' => 'Loop over een pagina met commentaar van deze foto.'
  },
  'helpvar commentLoop bodyText' => {
    'lastUpdated' => '1201262701',
    'message' => 'Het hoofdveld van het commentaar.'
  },
  'helpvar commentLoop creationDate' => {
    'lastUpdated' => '1201262722',
    'message' => 'De creatie datum van het commentaar'
  },
  'helpvar commentLoop url_deleteComment' => {
    'lastUpdated' => '1203437104',
    'message' => 'De URL om dit commentaar te verwijderen'
  },
  'helpvar commentLoop userId' => {
    'lastUpdated' => '1201262758',
    'message' => 'Het gebruikers id van de gebruiker die het commentaar heeft gemaakt.'
  },
  'helpvar commentLoop username' => {
    'lastUpdated' => '1201262788',
    'message' => 'De gebruikersnaam van de gebruiker die dit commentaar heeft toegevoegd.'
  },
  'helpvar commentLoop visitorIp' => {
    'lastUpdated' => '1201262818',
    'message' => 'Als de gebruiker een bezoeker is, is dit het IP adres van de gebruiker.'
  },
  'helpvar commentLoop_pageBar' => {
    'lastUpdated' => '1201262848',
    'message' => 'De balk waarmee genavigeerd kan worden in de pagina\'s met commentaar.'
  },
  'helpvar error' => {
    'lastUpdated' => '1204901170',
    'message' => 'Het i18n fouten bericht'
  },
  'helpvar errors' => {
    'lastUpdated' => '1204901200',
    'message' => 'Een functie die de foutberichten aan de gebruiker laat zien.'
  },
  'helpvar exifLoop' => {
    'lastUpdated' => '1201264066',
    'message' => 'Een loop voor de EXIF tags'
  },
  'helpvar exifLoop tag' => {
    'lastUpdated' => '1201263970',
    'message' => 'De naam van de EXIF tag'
  },
  'helpvar exifLoop value' => {
    'lastUpdated' => '1201263953',
    'message' => 'De waarde van de EXIF tag'
  },
  'helpvar exif_' => {
    'lastUpdated' => '1201264050',
    'message' => 'Er kan met een naam verwezen worden naar elke EXIF tag.'
  },
  'helpvar fileUrl' => {
    'lastUpdated' => '1201263925',
    'message' => 'Het URL naar de foto met normaal formaat'
  },
  'helpvar firstFile_thumbnailUrl' => {
    'lastUpdated' => '1270629892',
    'message' => 'De URL van het miniatuur van het eerste bestand in het album.'
  },
  'helpvar firstFile_title' => {
    'lastUpdated' => '1270629906',
    'message' => 'De titel van het eerste bestand in het album.'
  },
  'helpvar firstFile_url' => {
    'lastUpdated' => '1270629918',
    'message' => 'De URL van het eerste bestand in het album.'
  },
  'helpvar form_end' => {
    'lastUpdated' => '1201263902',
    'message' => 'Beeindig het formulier'
  },
  'helpvar form_friendsOnly' => {
    'lastUpdated' => '1201263886',
    'message' => 'Deze foto alleen voor vienden zichtbaar maken?'
  },
  'helpvar form_keywords' => {
    'lastUpdated' => '1201264551',
    'message' => 'De trefwoorden van de foto'
  },
  'helpvar form_location' => {
    'lastUpdated' => '1201263749',
    'message' => 'De locatie waar de foto is genomen.'
  },
  'helpvar form_parentId' => {
    'lastUpdated' => '1201263729',
    'message' => 'Selecteer in welk album de snelkoppeling gemaakt moet worden.'
  },
  'helpvar form_photo' => {
    'lastUpdated' => '1201263699',
    'message' => 'De foto die geupload moet worden.'
  },
  'helpvar form_start' => {
    'lastUpdated' => '1201263514',
    'message' => 'Start het formulier.'
  },
  'helpvar form_submit' => {
    'lastUpdated' => '1201263500',
    'message' => 'Verstuur het formulier.'
  },
  'helpvar form_synopsis' => {
    'lastUpdated' => '1201263480',
    'message' => 'Het bijschrift van de foto.'
  },
  'helpvar form_title' => {
    'lastUpdated' => '1201263379',
    'message' => 'De titel van deze foto.'
  },
  'helpvar gallery_menuTitle' => {
    'lastUpdated' => '1213629990',
    'message' => 'De menu titel van de galerie die dit bestand bevat'
  },
  'helpvar gallery_title' => {
    'lastUpdated' => '1213630017',
    'message' => 'De titel van de galerie die dit bestand bevat'
  },
  'helpvar gallery_url' => {
    'lastUpdated' => '1213630043',
    'message' => 'Het URL van de galerie die dit bestand bevat'
  },
  'helpvar isNewPhoto' => {
    'lastUpdated' => '1204031388',
    'message' => 'Deze variabele is waar als de gebruiker een nieuwe foto aan het toevoegen is.'
  },
  'helpvar isPending' => {
    'lastUpdated' => '1213630100',
    'message' => 'Een indicatie dat de foto nog niet is goedgekeurd. Gebruikers die de foto kunnen bewerken mogen deze bekijken voordat de foto wordt goedgekeurd.'
  },
  'helpvar keyword' => {
    'lastUpdated' => '1206953766',
    'message' => 'Het trefwoord'
  },
  'helpvar keywords' => {
    'lastUpdated' => '1206954207',
    'message' => 'Een functie met alle trefwoorden die bij deze foto horen.'
  },
  'helpvar lastFile_thumbnailUrl' => {
    'lastUpdated' => '1270629942',
    'message' => 'De URL van het miniatuur van het laatste bestand in het album.'
  },
  'helpvar lastFile_title' => {
    'lastUpdated' => '1270629955',
    'message' => 'De titel van het laatste bestand in het album.'
  },
  'helpvar lastFile_url' => {
    'lastUpdated' => '1270629964',
    'message' => 'De URL van het laatste bestand in het album.'
  },
  'helpvar nextFile_thumbnailUrl' => {
    'lastUpdated' => '1270630004',
    'message' => 'De URL van het miniatuur van het volgende bestand in het album. Ongedefinieerd als er geen volgend bestand is.'
  },
  'helpvar nextFile_title' => {
    'lastUpdated' => '1270630016',
    'message' => 'De titel van het volgende bestand in het album. Ongedefinieerd als er geen volgend bestand is.'
  },
  'helpvar nextFile_url' => {
    'lastUpdated' => '1270630032',
    'message' => 'De URL van het volgende bestand in het album. Ongedefinieerd als er geen volgend bestand is.'
  },
  'helpvar numberOfComments' => {
    'lastUpdated' => '1201263116',
    'message' => 'Het totale aantal commentaren dat gegeven is op deze foto.'
  },
  'helpvar ownerAlias' => {
    'lastUpdated' => '1275487008',
    'message' => 'De alias van de gebruiker die deze foto gepost heeft. Als er geen alias is, wordt de gebruikersnaam gebruikt.'
  },
  'helpvar ownerId' => {
    'lastUpdated' => '1275487027',
    'message' => 'De Id van de gebruiker die de foto heeft gepost.'
  },
  'helpvar ownerProfileUrl' => {
    'lastUpdated' => '1275487051',
    'message' => 'De URL van het profiel van de gebruiker die de foto heeft gepost.'
  },
  'helpvar ownerUsername' => {
    'lastUpdated' => '1201263086',
    'message' => 'De gebruikersnaam van de gebruiker, die deze foto heeft toegevoegd.'
  },
  'helpvar previousFile_thumbnailUrl' => {
    'lastUpdated' => '1270630135',
    'message' => 'De URL van het miniatuur van het vorige bestand in het album. Ongedefinieerd als er geen vorig bestand is.'
  },
  'helpvar previousFile_title' => {
    'lastUpdated' => '1270630069',
    'message' => 'De titel van het vorige bestand in het album. Ongedefinieerd als er geen vorig bestand is.'
  },
  'helpvar previousFile_url' => {
    'lastUpdated' => '1270630124',
    'message' => 'De URL van het vorige bestand in het album. Ongedefinieerd als er geen vorig bestand is.'
  },
  'helpvar resolutions_' => {
    'lastUpdated' => '1213630168',
    'message' => 'Een URL verwijzing naar een bekende resolutie. &quot;800&quot; resolutie wordt dan &quot;resolutions_800&quot;'
  },
  'helpvar resolutions_loop' => {
    'lastUpdated' => '1201263055',
    'message' => 'De voor download beschikbare resoluties die deze foto heeft.'
  },
  'helpvar resolutions_loop resolution' => {
    'lastUpdated' => '1213630182',
    'message' => 'De resolutie van de foto'
  },
  'helpvar resolutions_loop url_download' => {
    'lastUpdated' => '1201263019',
    'message' => 'Het URL naar de downloadresoluties.'
  },
  'helpvar synopsis_textonly' => {
    'lastUpdated' => '1206954236',
    'message' => 'Het &quot;samenvatting&quot; veld zonder HTML.'
  },
  'helpvar thumbnailUrl' => {
    'lastUpdated' => '1201262987',
    'message' => 'Het URL naar een miniatuur van deze foto.'
  },
  'helpvar url_addArchive' => {
    'lastUpdated' => '1201262962',
    'message' => 'Het URL voor het toevoegen van een archief aan het bovenliggende album.'
  },
  'helpvar url_album' => {
    'lastUpdated' => '1206954258',
    'message' => 'Het URL van het album waar dit bestand in zit.'
  },
  'helpvar url_delete' => {
    'lastUpdated' => '1201193785',
    'message' => 'Het URL waar deze foto verwijderd kan worden.'
  },
  'helpvar url_demote' => {
    'lastUpdated' => '1201264177',
    'message' => 'Het URL om de foto in rang te laten dalen. Brengt de gebruiker direct terug naar het bewerkingsformulier van het bovenliggende galerie album.'
  },
  'helpvar url_edit' => {
    'lastUpdated' => '1201193924',
    'message' => 'Het URL waar deze foto bewerkt kan worden.'
  },
  'helpvar url_gallery' => {
    'lastUpdated' => '1201264203',
    'message' => 'Het URL naar de galerie die deze foto bevat.'
  },
  'helpvar url_listFilesForOwner' => {
    'lastUpdated' => '1201262928',
    'message' => 'Het URL om bestanden en albums in een lijst te zetten, die door de eigenaar van deze foto toegevoegd zijn.'
  },
  'helpvar url_makeShortcut' => {
    'lastUpdated' => '1201262876',
    'message' => 'Het URL waar een snelkoppeling naar deze foto gemaakt wordt.'
  },
  'helpvar url_promote' => {
    'lastUpdated' => '1201264242',
    'message' => 'Het URL om de foto in rang te laten stijgen. Brengt de gebruiker direct terug naar het bewerkingsformulier van het bovenliggende galerie album.'
  },
  'helpvar url_searchKeyword' => {
    'lastUpdated' => '1206954409',
    'message' => 'Het URL naar de Galerie zoek pagina met dit trefwoord.'
  },
  'helpvar url_searchKeywordUser' => {
    'lastUpdated' => '1206954468',
    'message' => 'Een URL naar de Galerie zoek pagina met dit trefwoord. Het beperkt de zoekopdracht tot foto\'s van deze gebruiker.'
  },
  'helpvar url_slideshow' => {
    'lastUpdated' => '1206955061',
    'message' => 'Het URL naar de diavoorstelling van het album waar dit bestand in zit.'
  },
  'helpvar url_thumbnails' => {
    'lastUpdated' => '1206957089',
    'message' => 'Het URL naar de miniaturen van het album waar dit bestand in zit.'
  },
  'helpvar url_yes' => {
    'lastUpdated' => '1201193747',
    'message' => 'Bevestig het verwijderen van deze foto.'
  },
  'hide' => {
    'lastUpdated' => '1231520755',
    'message' => 'Verbergen'
  },
  'more details' => {
    'lastUpdated' => '1231520764',
    'message' => 'Meer details'
  },
  'save message' => {
    'lastUpdated' => '1201193720',
    'message' => 'Uw foto is ingezonden voor goedkeuring en verwerking. <a href="%s">Bekijk foto</a>. <a href="%s">Voeg nog een foto toe</a>.'
  },
  'template assetName' => {
    'lastUpdated' => '1204031395',
    'message' => 'Foto'
  },
  'template comment add title' => {
    'lastUpdated' => '1216986255',
    'message' => 'Voeg commentaar toe'
  },
  'template comment creationDate' => {
    'lastUpdated' => '1203437434',
    'message' => 'Gepost op'
  },
  'template comment delete confirm' => {
    'lastUpdated' => '1203437416',
    'message' => 'Weet u zeker dat u dit commentaar wilt verwijderen?'
  },
  'template comment edit comment' => {
    'lastUpdated' => '1231520773',
    'message' => 'Bewerk commentaar'
  },
  'template comment edit title' => {
    'lastUpdated' => '1216986263',
    'message' => 'Bewerk commentaar'
  },
  'template comments title' => {
    'lastUpdated' => '1203437402',
    'message' => 'Commentaar'
  },
  'template creationDate' => {
    'lastUpdated' => '1203437396',
    'message' => 'Geupload op'
  },
  'template delete albums' => {
    'lastUpdated' => '1206957107',
    'message' => 'De foto zit momenteel in de volgende albums:'
  },
  'template delete message' => {
    'lastUpdated' => '1236854826',
    'message' => 'Weet je zeker dat je deze foto wilt verwijderen?'
  },
  'template error happened' => {
    'lastUpdated' => '1204901353',
    'message' => 'Een fout is opgetreden tijdens het verwerken van het aanvraag.'
  },
  'template fileUrl' => {
    'lastUpdated' => '1203437381',
    'message' => 'Bekijk foto op volledige grootte'
  },
  'template filesForUser' => {
    'lastUpdated' => '1275487060',
    'message' => 'meer foto\'s'
  },
  'template friendsOnly label' => {
    'lastUpdated' => '1203437359',
    'message' => 'Privacy'
  },
  'template friendsOnly no' => {
    'lastUpdated' => '1203437353',
    'message' => 'Publiek'
  },
  'template friendsOnly yes' => {
    'lastUpdated' => '1203516882',
    'message' => 'Alleen vrienden'
  },
  'template keywords' => {
    'lastUpdated' => '1203516975',
    'message' => 'Label'
  },
  'template location' => {
    'lastUpdated' => '1203437252',
    'message' => 'Locatie'
  },
  'template makeShortcut album' => {
    'lastUpdated' => '1206957136',
    'message' => 'Album'
  },
  'template makeShortcut file' => {
    'lastUpdated' => '1206957142',
    'message' => 'Bestand'
  },
  'template makeShortcut title' => {
    'lastUpdated' => '1206957168',
    'message' => 'Kruislings publiceren'
  },
  'template url_album' => {
    'lastUpdated' => '1203437259',
    'message' => 'Terug naar album'
  },
  'template url_delete' => {
    'lastUpdated' => '1203437281',
    'message' => 'Verwijder foto'
  },
  'template url_deleteComment' => {
    'lastUpdated' => '1203437277',
    'message' => 'verwijder'
  },
  'template url_edit' => {
    'lastUpdated' => '1203437289',
    'message' => 'Bewerk foto'
  },
  'template url_makeShortcut' => {
    'lastUpdated' => '1203516997',
    'message' => 'Publiceren via snelkoppeling'
  },
  'template view available resolutions' => {
    'lastUpdated' => '1231520786',
    'message' => 'Beschikbare resoluties'
  },
  'template view details' => {
    'lastUpdated' => '1231520792',
    'message' => 'Details'
  },
  'template view title' => {
    'lastUpdated' => '1203437305',
    'message' => 'Foto details'
  },
  'template views' => {
    'lastUpdated' => '1203516817',
    'message' => 'Bezoeken'
  }
}
;

1;
